@@ -282,10 +282,12 @@ class RauthOAuth2(OAuth2Service, RauthServiceMixin):
 
         return redirect(self.get_authorize_url(redirect_uri=callback, **authorize_params))
 
-    def authorized_handler(self, f):
+    def authorized_handler(self, method='POST'):
         '''
         The decorator to assign a function that will be called after
-        authorization is complete.
+        authorization is complete. By default, a `POST` request is used to
+        fetch the access token. If you need to send a `GET` request, use the
+        ``authorized_handler(method='GET')`` to do so.
 
         It should be a route that takes two parameters: `response` and
         `access_token`.
@@ -293,24 +295,26 @@ class RauthOAuth2(OAuth2Service, RauthServiceMixin):
         If `response` is ``access_denied``, then the user denied access to
             his/her information.
         '''
-        @wraps(f)
-        def decorated(*args, **kwargs):
-            resp = access_token = None
-            if 'error' in request.args and request.args['error'] == ACCESS_DENIED:
-                resp = ACCESS_DENIED
-            elif 'code' in request.args:
-                resp = RauthResponse(self.get_access_token(data={
-                    'code': request.args['code'],
-                    'redirect_uri': session.pop(self._session_key('redirect_uri'), None)
-                }))
+        def create_authorized_handler(f):
+            @wraps(f)
+            def decorated(*args, **kwargs):
+                resp = access_token = None
+                if 'error' in request.args and request.args['error'] == ACCESS_DENIED:
+                    resp = ACCESS_DENIED
+                elif 'code' in request.args:
+                    resp = RauthResponse(self.get_access_token(method=method, data={
+                        'code': request.args['code'],
+                        'redirect_uri': session.pop(self._session_key('redirect_uri'), None)
+                    }))
 
-                if resp.status != 200:
-                    raise RauthException('An error occurred while getting the OAuth 2.0 access_token', resp)
+                    if resp.status != 200:
+                        raise RauthException('An error occurred while getting the OAuth 2.0 access_token', resp)
 
-                access_token = resp.content.get('access_token')
+                    access_token = resp.content.get('access_token')
 
-            return f(*((resp, access_token) + args), **kwargs)
-        return decorated
+                return f(*((resp, access_token) + args), **kwargs)
+            return decorated
+        return create_authorized_handler
 
     def request(self, method, url, access_token=None, **kwargs):
         '''
@@ -376,13 +380,16 @@ class RauthOAuth1(OAuth1Service, RauthServiceMixin):
 
         # save the request_token in the session
         session[self._session_key('request_token')] = request_token
-
+        
         # pass the token and any user-provided parameters
         return redirect(self.get_authorize_url(request_token['request_token']))
 
-    def authorized_handler(self, f):
+    def authorized_handler(self, method='POST'):
         '''
         The handler should expect two arguments: `response` and `oauth_token`.
+        By default, a `POST` request is used to fetch the access token. If you
+        need to send a `GET` request, use the
+        ``authorized_handler(method='GET')`` to do so.
 
         If `response` is ``None`` then the user *most-likely* denied access
             to his/her information. Since OAuth 1.0a does not specify a
@@ -390,21 +397,25 @@ class RauthOAuth1(OAuth1Service, RauthServiceMixin):
             authorization, you will need to figure out how the endpoint that
             your are interacting with delineates this edge-case.
         '''
-        @wraps(f)
-        def decorated(*args, **kwargs):
-            resp = oauth_token = None
-            if 'oauth_verifier' in request.args:
-                resp = RauthResponse(self.get_access_token(data={
-                    'oauth_verifier': request.args['oauth_verifier']
-                }, **session.pop(self._session_key('request_token'), {})))
+        def create_authorized_handler(f):
+            @wraps(f)
+            def decorated(*args, **kwargs):
+                resp = oauth_token = None
+                if 'oauth_verifier' in request.args:
+                    resp = RauthResponse(self.get_access_token(
+                        method=method,
+                        data={'oauth_verifier': request.args['oauth_verifier']},
+                        **session.pop(self._session_key('request_token'), {}))
+                    )
 
-                if resp.status != 200:
-                    raise RauthException('An error occurred during OAuth 1.0a authorization', resp)
+                    if resp.status != 200:
+                        raise RauthException('An error occurred during OAuth 1.0a authorization', resp)
 
-                oauth_token = (resp.content.get('oauth_token'), resp.content.get('oauth_token_secret'))
+                    oauth_token = (resp.content.get('oauth_token'), resp.content.get('oauth_token_secret'))
 
-            return f(*((resp, oauth_token) + args), **kwargs)
-        return decorated
+                return f(*((resp, oauth_token) + args), **kwargs)
+            return decorated
+        return create_authorized_handler
 
     def request(self, method, url, oauth_token=None, **kwargs):
         '''
@@ -453,30 +464,33 @@ class RauthOfly(OflyService, RauthServiceMixin):
         # pass the callback and any user-provided parameters
         return redirect(self.get_authorize_url(redirect_uri=callback, **authorize_params))
 
-    def authorized_handler(self, f):
+    def authorized_handler(self, method='POST'):
         '''
         The handler should expect two arguments: `response` and `oflyUserid`.
+        The `method` parameter is unused.
 
         If `response` is ``access_denied``, then the user denied access to
             his/her information.
         '''
-        @wraps(f)
-        def decorated(*args, **kwargs):
-            resp = oflyUserid = None
-            if 'oflyUserid' in request.args:
-                if request.args['oflyUserid'] == 'no-grant':
-                    resp = ACCESS_DENIED
-                else:
-                    resp = {
-                        'oflyUserid': request.args['oflyUserid'],
-                        'oflyAppId': request.args.get('oflyAppId'),
-                        'oflyUserEmail': request.args.get('oflyUserEmail')
-                    }
+        def create_authorized_handler(f):
+            @wraps(f)
+            def decorated(*args, **kwargs):
+                resp = oflyUserid = None
+                if 'oflyUserid' in request.args:
+                    if request.args['oflyUserid'] == 'no-grant':
+                        resp = ACCESS_DENIED
+                    else:
+                        resp = {
+                            'oflyUserid': request.args['oflyUserid'],
+                            'oflyAppId': request.args.get('oflyAppId'),
+                            'oflyUserEmail': request.args.get('oflyUserEmail')
+                        }
 
-                    oflyUserid = request.args['oflyUserid']
+                        oflyUserid = request.args['oflyUserid']
 
-            return f(*((resp, oflyUserid) + args), **kwargs)
-        return decorated
+                return f(*((resp, oflyUserid) + args), **kwargs)
+            return decorated
+        return create_authorized_handler
 
     def request(self, method, url, oflyUserid=None, **kwargs):
         '''
